@@ -6,9 +6,10 @@
 # @Desc    : 后台运行python文件类
 import sys, os
 import time
-from threading import Thread
+
+
 class Daemon:
-    def __init__(self,target,args=(),kwargs=None,stdin='/dev/null', stdout=None, stderr=None):
+    def __init__(self, target, args=(), kwargs=None, stdin='/dev/null', pid_file=None, stdout=None, stderr=None):
         '''
         :param target:执行的函数名
         :param args:执行函数的位置参数，没有参数可以不写
@@ -19,13 +20,14 @@ class Daemon:
         '''
         self.target = target
         self.args = args
-        self.kwargs = kwargs if kwargs !=None else {}
+        self.kwargs = kwargs if kwargs != None else {}
         self.__stdin = stdin
-        self.__stdout = stdout if stdout else '/tmp/%s_out.log'%self.target.__name__
-        self.__stderr = stderr if stderr else '/tmp/%s_err.log'%self.target.__name__
+        self.__pid_file = pid_file
+        self.__stdout = stdout if stdout else '/tmp/%s_out.log' % self.target.__name__
+        self.__stderr = stderr if stderr else '/tmp/%s_err.log' % self.target.__name__
 
     def __daemonize(self):
-        #这个函数的实现是抄的，https://cloud.tencent.com/developer/article/1567443
+        # 这个函数的实现是抄的，https://cloud.tencent.com/developer/article/1567443
         # 重定向标准文件描述符（默认情况下定向到/dev/null）
         try:
             pid = os.fork()
@@ -50,30 +52,35 @@ class Daemon:
             sys.stderr.write("fork #2 failed: (%d) %s\n" % (e.errno, e.strerror))
             sys.exit(1)
         for f in sys.stdout, sys.stderr: f.flush()
-        si = open(self.__stdin, 'r',encoding='utf-8')
-        so = open(self.__stdout, 'a+',encoding='utf-8')
-        se = open(self.__stderr, 'a+',encoding='utf-8')
+        si = open(self.__stdin, 'r', encoding='utf-8')
+        so = open(self.__stdout, 'a+', encoding='utf-8')
+        se = open(self.__stderr, 'a+', encoding='utf-8')
+        print('pid', os.getpid())
+        self.__write_pid(os.getpid())
         os.dup2(si.fileno(), sys.stdin.fileno())  # dup2函数原子化关闭和复制文件描述符
         os.dup2(so.fileno(), sys.stdout.fileno())
         os.dup2(se.fileno(), sys.stderr.fileno())
-        print('pid',os.getpid())
+
+    def __write_pid(self, pid):
+        if self.__pid_file:
+            with open(self.__pid_file) as fw:
+                fw.write(str(pid))
 
     def start(self):
         '''启动函数'''
         self.__daemonize()
-        return self.target(*self.args,**self.kwargs)
+        return self.target(*self.args, **self.kwargs)
 
 
-def example(a,b,port=3306,country='china'):
+def example(a, b, port=3306, country='china'):
     '''测试用的函数'''
-    print(a,b,port,country)
+    print(a, b, port, country)
     while True:
         time.sleep(1)
         print('example func')
 
 
 if __name__ == '__main__':
-    d = Daemon(target=example,args=(1,2),kwargs={'country':'japan'})
+    d = Daemon(target=example, args=(1, 2), kwargs={'country': 'japan'})
     d.start()
-    #运行完之后，会一直在后台运行这个python文件，请手动kill
-
+    # 运行完之后，会一直在后台运行这个python文件，请手动kill
